@@ -22,25 +22,23 @@
 #include "chat_manager.h"
 #include "config_file.h"
 #include "configuration_window_widgets.h"
+#include "custom_input.h"
 #include "debug.h"
+#include "exports.h"
 #include "pending_msgs.h"
 
-LedNotify* led_notify_session;
+LedNotify* led_notify;
 
-extern "C" int led_notify_init()
+extern "C" KADU_EXPORT int led_notify_init( bool firstLoad )
 {
-	kdebugf();
-	led_notify_session = new LedNotify();
-	kdebugf2();
+	led_notify = new LedNotify();
 	return 0;
 }
 
-extern "C" void led_notify_close()
+extern "C" KADU_EXPORT void led_notify_close()
 {
-	kdebugf();
-	delete led_notify_session;
-	led_notify_session = NULL;
-	kdebugf2();
+	delete led_notify;
+	led_notify = 0;
 }
 
 LedNotify::LedNotify(QObject* parent, const char* name)
@@ -56,11 +54,13 @@ LedNotify::LedNotify(QObject* parent, const char* name)
 	notification_manager->registerNotifier( "Scroll Lock LED", this );
 	connect( &pending, SIGNAL(messageFromUserDeleted(UserListElement)), this, SLOT(messageReceived(UserListElement)) );
 	connect( chat_manager, SIGNAL(chatWidgetActivated(ChatWidget*)), this, SLOT(chatWidgetActivated(ChatWidget*)) );
+	connect( chat_manager, SIGNAL(chatWidgetDestroying(ChatWidget*)), this, SLOT(chatWidgetActivated(ChatWidget*)) );
 }
 
 LedNotify::~LedNotify()
 {
 	disconnect( chat_manager, SIGNAL(chatWidgetActivated(ChatWidget*)), this, SLOT(chatWidgetActivated(ChatWidget*)) );
+	disconnect( chat_manager, SIGNAL(chatWidgetDestroying(ChatWidget*)), this, SLOT(chatWidgetActivated(ChatWidget*)) );
 	disconnect( &pending, SIGNAL(messageFromUserDeleted(UserListElement)), this, SLOT(messageReceived(UserListElement)) );
 	notification_manager->unregisterNotifier("Scroll Lock LED");
 	MainConfigurationWindow::unregisterUiFile(dataPath("kadu/modules/configuration/led_notify.ui"), this);
@@ -87,11 +87,18 @@ void LedNotify::notify( Notification *notification )
 	{
 		const UserListElements& senders = notification->userListElements();
 		ChatWidget* chat = chat_manager->findChatWidget( senders );
-		if( chat != NULL && !chat->hasFocus() )
+		if( chat != 0 )
 		{
-			msgChats_.push_back( chat );
-			msgBlinking_ = true;
-			blinker_.startInfinite();
+			if( !chat->edit()->hasFocus() )
+			{
+				msgChats_.insert( chat );
+				msgBlinking_ = true;
+				blinker_.startInfinite();
+			}
+			else if( !config_file.readBoolEntry("Notify", "NewMessageOnlyIfInactive") )
+			{
+				blinker_.startFinite();
+			}
 		}
 	}
 	else
