@@ -1,49 +1,39 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS>
 <context>
     <name>Wizard</name>
     <message>
-        <location filename="../wizard.cpp" line="90"/>
         <source>Kadu Wizard</source>
         <translation>Créateur configuration Kadu</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="331"/>
         <source>I have a number</source>
         <translation>J&apos;ai possède déjà le numéro</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="335"/>
         <source>Gadu-gadu number</source>
         <translation>Numéro GG</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="340"/>
         <source>Gadu-gadu password</source>
         <translation>Mot de passe</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="346"/>
         <source>Import contacts</source>
         <translation>Importation de contacts</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="365"/>
         <source>Your e-mail address</source>
         <translation>Adresse e-mail</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="457"/>
         <source>Choose your browser</source>
         <translation>Choix de navigateur</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="647"/>
         <source>Sound</source>
         <translation>Son</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="221"/>
         <source>Error data typed in required fields.
 
 Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
@@ -51,49 +41,24 @@ Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new pa
 Le mot de passe devrait être le même (&quot;nouveau mot de passe&quot; et &quot;retappez le nouveau mot de passe&quot; dans les deux champs!</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="274"/>
         <source>An error has occured while registration. Please try again later.</source>
         <translation>Erreur lors d&apos;enregistrement.Veuillez essayer plus tard.</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="99"/>
-        <source>Finish</source>
-        <translation>Terminé</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="102"/>
-        <source>Next &gt;</source>
-        <translation>Suivant &gt;</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="105"/>
-        <source>&lt; Back</source>
-        <translation>&lt; En arrière</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="107"/>
-        <source>Cancel</source>
-        <translation>Annule</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="310"/>
         <source>User list wasn&apos;t imported because of some error</source>
         <translation>Erreur d&apos;importation de la liste de contacts</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="370"/>
         <source>Register</source>
         <translation>Enregistrement</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="266"/>
         <source>Registration was successful.
 You UIN is: </source>
         <translation>Enregistrement avec success.
 Votre VIN numero Kadu est :</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="266"/>
         <source>
 Account configuration was saved.
 Press Ok to continue</source>
@@ -101,162 +66,118 @@ Press Ok to continue</source>
 Appuyer suivant pour continuer</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="227"/>
         <source>Please fill out all fields</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="233"/>
         <source>Email address you have entered is not valid</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="323"/>
-        <source>Account</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="350"/>
         <source>I don&apos;t have a number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="353"/>
         <source>New password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="359"/>
         <source>Retype password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="449"/>
-        <source>WWW browser</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="486"/>
         <source>Specify path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="460"/>
         <source>Konqueror</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="461"/>
         <source>Opera</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="464"/>
         <source>Mozilla</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="465"/>
         <source>Mozilla Firefox</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="466"/>
         <source>Dillo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="467"/>
         <source>Galeon</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="468"/>
         <source>Safari</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="472"/>
         <source>Custom browser</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="476"/>
-        <source>e-mail client</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="484"/>
         <source>Choose your e-mail client</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="487"/>
         <source>KMail</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="488"/>
         <source>Thunderbird</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="489"/>
         <source>SeaMonkey</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="490"/>
         <source>Evolution</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="494"/>
         <source>Custom e-mail client</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="502"/>
         <source>Applications</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="505"/>
         <source>&lt;p&gt;Please setup Kadu for working with your favourite WWW browser and email program.&lt;/p&gt;&lt;p&gt;Kadu will use these for opening various links from messages and user&apos;s descriptions&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="599"/>
         <source>Test sound</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="652"/>
         <source>&lt;p&gt;Please select your sound driver for sound notifications. If you don&apos;t want sound notifications, use None driver.&lt;/p&gt;&lt;p&gt;If you don&apos;t know which driver to use, just check every ony with Test sound button.Don&apos;t forget to unmute your system before!&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="400"/>
         <source>&lt;h3&gt;Welcome in Kadu&lt;/h3&gt;&lt;h4&gt;the Gadu-gadu network client for *nix and MacOS X.&lt;/h4&gt;&lt;p&gt;This is first time you launch Kadu. This wizard will help you to configure the basic settings of Kadu. If you are experienced Kadu user you may omit the wizard by clicking Cancel.&lt;/p&gt;&lt;p&gt;Please enter your account data. If you don&apos;t have one, you can create new here.&lt;/p&gt;&lt;p&gt;E-mail address is needed when you want to recover lost password to account&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="395"/>
         <source>Gadu-gadu account</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="595"/>
         <source>Sound system</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="462"/>
         <source>Opera (new tab)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="530"/>
         <source>Not found</source>
         <translation type="unfinished"></translation>
     </message>
@@ -264,12 +185,10 @@ Appuyer suivant pour continuer</translation>
 <context>
     <name>WizardStarter</name>
     <message>
-        <location filename="../wizard.cpp" line="62"/>
         <source>Configuration Wizard</source>
         <translation>Créateur de configuration</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="203"/>
         <source>User list couldn&apos;t be imported</source>
         <translation type="unfinished"></translation>
     </message>
