@@ -14,23 +14,25 @@
  * @ingroup hints
  * @{
  */
-extern "C" int hints_init()
+extern "C" KADU_EXPORT int hints_init(bool firstLoad)
 {
 	kdebugf();
-	
-	hint_manager=new HintManager(NULL, "hint_manager");
-	
+
+	hint_manager = new HintManager();
+	MainConfigurationWindow::registerUiFile(dataPath("kadu/modules/configuration/hints.ui"), hint_manager);
+
 	kdebugf2();
 	return 0;
 }
 
-extern "C" void hints_close()
+extern "C" KADU_EXPORT void hints_close()
 {
 	kdebugf();
-	
+
+	MainConfigurationWindow::unregisterUiFile(dataPath("kadu/modules/configuration/hints.ui"), hint_manager);
 	delete hint_manager;
-	hint_manager=NULL;
-	
+	hint_manager = 0;
+
 	kdebugf2();
 }
 
