@@ -19,6 +19,7 @@
 #include "html_document.h"
 #include "kadu.h"
 #include "misc.h"
+#include "message_box.h"
 
 #include "history.h"
 
@@ -73,7 +74,7 @@ QString HistoryManager::getFileNameByUinsList(UinsList uins)
 	return fname;
 }
 
-void HistoryManager::appendMessage(UinsList uins, UinType uin, const QString &msg, bool own, time_t czas, bool chat, time_t arriveTime)
+void HistoryManager::appendMessage(UinsList uins, UinType uin, const QString &msg, bool own, time_t serverTime, bool chat, time_t arriveTime)
 {
 	kdebugf();
 	QFile f, fidx;
@@ -84,7 +85,7 @@ void HistoryManager::appendMessage(UinsList uins, UinType uin, const QString &ms
 
 	convHist2ekgForm(uins);
 	fname.append(getFileNameByUinsList(uins));
-	updateMessageDates(uins);
+	updateMessageDates(uins, arriveTime);
 
 	if (own)
 		if (chat)
@@ -104,7 +105,7 @@ void HistoryManager::appendMessage(UinsList uins, UinType uin, const QString &ms
 	linelist.append(text2csv(nick));
 	linelist.append(QString::number(arriveTime));
 	if (!own)
-		linelist.append(QString::number(czas));
+		linelist.append(QString::number(serverTime));
 	linelist.append(text2csv(msg));
 	line = linelist.join(",");
 
@@ -112,6 +113,7 @@ void HistoryManager::appendMessage(UinsList uins, UinType uin, const QString &ms
 	if (!(f.open(QIODevice::WriteOnly | QIODevice::Append)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(fname));
+		MessageBox::msg(tr("Error opening history file ") + fname);
 		return;
 	}
 
@@ -141,6 +143,7 @@ void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 	QString altnick, line, fname;
 	UinType uin = 0;
 	int offs;
+	time_t currentTime = time(NULL);
 
 	QString html_msg = msg;
 	HtmlDocument::escapeText(html_msg);
@@ -149,7 +152,7 @@ void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 
 	linelist.append("smssend");
 	linelist.append(mobile);
-	linelist.append(QString::number(time(NULL)));
+	linelist.append(QString::number(currentTime));
 	linelist.append(text2csv(html_msg));
 
 	foreach(const UserListElement &i, *userlist)
@@ -163,6 +166,7 @@ void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 	{
 		UinsList uins(uin);
 		convHist2ekgForm(uins);
+		updateMessageDates(uins, currentTime);
 		linelist.append(text2csv(altnick));
 		linelist.append(QString::number(uin));
 	}
@@ -173,6 +177,7 @@ void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 	if (!(f.open(QIODevice::WriteOnly | QIODevice::Append)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening sms history file\n");
+		MessageBox::msg(tr("Error opening sms history file ") + f.name());
 		return;
 	}
 
@@ -198,6 +203,7 @@ void HistoryManager::appendSms(const QString &mobile, const QString &msg)
 		if (!(f.open(QIODevice::WriteOnly | QIODevice::Append)))
 		{
 			kdebugmf(KDEBUG_ERROR, "Error opening sms history\n");
+			MessageBox::msg(tr("Error opening sms history file ") + f.name());
 			return;
 		}
 
@@ -288,6 +294,7 @@ void HistoryManager::appendStatus(UinType uin, const UserStatus &status)
 	if (!(f.open(QIODevice::WriteOnly | QIODevice::Append)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(fname));
+		MessageBox::msg(tr("Error opening history file ") + fname);
 		return;
 	}
 
@@ -313,8 +320,7 @@ void HistoryManager::removeHistory(const UinsList &uins)
 	kdebugf();
 
 	QString fname;
-	switch (QMessageBox::information(kadu, "Kadu", qApp->translate("@default",QT_TR_NOOP("Clear history?")),
-		qApp->translate("@default",QT_TR_NOOP("Yes")), qApp->translate("@default",QT_TR_NOOP("No")), QString::null, 1, 1))
+	switch (QMessageBox::information(kadu, "Kadu", tr("Clear history?"), tr("Yes"), tr("No"), QString::null, 1, 1))
 	{
 		case 0:
 			fname = ggPath("history/");
@@ -346,6 +352,7 @@ void HistoryManager::convHist2ekgForm(UinsList uins)
 	if (!(f.open(QIODevice::ReadWrite)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(fname));
+		MessageBox::msg(tr("Error opening history file ") + fname);
 		return;
 	}
 
@@ -354,6 +361,7 @@ void HistoryManager::convHist2ekgForm(UinsList uins)
 	if (!(fout.open(QIODevice::WriteOnly | QIODevice::Truncate)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening new history file %s\n", qPrintable(fnameout));
+		MessageBox::msg(tr("Error opening new history file ") + fnameout);
 		f.close();
 		return;
 	}
@@ -488,6 +496,7 @@ void HistoryManager::convSms2ekgForm()
 	if (!(f.open(QIODevice::ReadWrite)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening sms history file %s\n", qPrintable(fname));
+		MessageBox::msg(tr("Error opening sms history file ") + fname);
 		return;
 	}
 	fnameout = fname + ".new";
@@ -495,6 +504,7 @@ void HistoryManager::convSms2ekgForm()
 	if (!(fout.open(QIODevice::WriteOnly | QIODevice::Truncate)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening new sms history file %s\n", qPrintable(fnameout));
+		MessageBox::msg(tr("Error opening new sms history file ") + fnameout);
 		f.close();
 		return;
 	}
@@ -601,6 +611,7 @@ int HistoryManager::getHistoryEntriesCountPrivate(const QString &filename) const
 	if (!(f.open(QIODevice::ReadOnly)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(filename));
+		MessageBox::msg(tr("Error opening history file ") + filename);
 		return 0;
 	}
 	lines = f.size() / sizeof(int);
@@ -655,6 +666,7 @@ QList<HistoryEntry> HistoryManager::getHistoryEntries(UinsList uins, int from, i
 	if (!(f.open(QIODevice::ReadOnly)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(filename));
+		MessageBox::msg(tr("Error opening history file ") + filename);
 		return entries;
 	}
 
@@ -808,6 +820,10 @@ uint HistoryManager::getHistoryDate(QTextStream &stream)
 
 	line = stream.readLine();
 	tokens = mySplit(',', line);
+
+	if (tokens.count() < 1) /* Mantis 0001131 fix */
+		return 0;
+
 	type = types.findIndex(tokens[0]);
 	if (!type)
 		pos = 2;
@@ -817,7 +833,13 @@ uint HistoryManager::getHistoryDate(QTextStream &stream)
 		else
 			pos = 4;
 	kdebugf2();
-	return (tokens[pos].toUInt() / 86400);
+
+	if (pos < tokens.count())
+	{
+		return ((tokens[pos].toInt()) / 86400);
+	}
+	else
+		return 0;
 }
 
 QList<HistoryDate> HistoryManager::getHistoryDates(const UinsList &uins)
@@ -844,6 +866,7 @@ QList<HistoryDate> HistoryManager::getHistoryDates(const UinsList &uins)
 	if (!(f.open(QIODevice::ReadOnly)))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(filename));
+		MessageBox::msg(tr("Error opening history file ") + filename);
 		return entries;
 	}
 	QTextStream stream(&f);
@@ -955,13 +978,15 @@ void HistoryManager::buildIndexPrivate(const QString &filename)
 	Q_LONG read, written;
 	bool saved = false;
 
-	if (QFile::exists(fnameout))
-		return;
-	QFile fin(filename);
 	QFile fout(fnameout);
+	if (fout.exists() && fout.size() > 0)
+		return;
+
+	QFile fin(filename);
 	if (!fin.open(QIODevice::ReadOnly))
 	{
 		kdebugmf(KDEBUG_ERROR, "Error opening history file: %s\n", qPrintable(fin.name()));
+		MessageBox::msg(tr("Error opening history file ") + fin.name());
 		return;
 	}
 	if (!fout.open(QIODevice::WriteOnly | QIODevice::Truncate))
@@ -1022,32 +1047,33 @@ void HistoryManager::createMessageDates(const UinsList uins)
 	messageDatesFile.open(QIODevice::WriteOnly);
 	QDataStream messageDatesStream(&messageDatesFile);
 
-	QDate currentDate;
+	QDate currentDate = QDate::currentDate();
 	HistoryEntry entry;
 	foreach (entry, entries)
 	{
-		if (entry.date.date() != currentDate && currentDate.isValid())
+		if (entry.date.date() != currentDate && entry.date.date().isValid())
 		{
-			messageDatesStream << currentDate;
+			messageDatesStream << entry.date.date();
 			currentDate = entry.date.date();
 		}
-		else if (!currentDate.isValid())
-			currentDate = entry.date.date();
 	}
 
+	messageDatesFile.flush();
 	messageDatesFile.close();
 
 	if (currentDate.isValid())
 		LastDate[uins] = currentDate;
 }
 
-void HistoryManager::updateMessageDates(const UinsList uins)
+void HistoryManager::updateMessageDates(const UinsList uins, time_t receiveTime)
 {
-	QDate date = QDate::currentDate();
+	QDateTime date;
+	date.setTime_t(receiveTime);
 	if (LastDate.contains(uins))
-		if (LastDate[uins] == date)
+		if (LastDate[uins] == date.date())
 			return;
 
+	kdebugmf(KDEBUG_INFO, "Appending date '%s' to message dates\n", qPrintable(date.date().toString("yyyy.MM.dd")));
 	QFile messageDatesFile(ggPath("history/") + getFileNameByUinsList(uins) + ".message_dates");
 	if (!messageDatesFile.exists())
 	{
@@ -1055,18 +1081,23 @@ void HistoryManager::updateMessageDates(const UinsList uins)
 		return;
 	}
 
-	messageDatesFile.open(QIODevice::WriteOnly | QIODevice::Append);
+	if (!messageDatesFile.open(QIODevice::WriteOnly | QIODevice::Append))
+	{
+		kdebugmf(KDEBUG_ERROR, "Error opening history file %s\n", qPrintable(messageDatesFile.fileName()));
+	  	MessageBox::msg(tr("Error opening history file ") + messageDatesFile.fileName());
+	}
+	
 	QDataStream messageDatesStream(&messageDatesFile);
-	messageDatesStream << date;
+	messageDatesStream << date.date();
 	messageDatesFile.close();
 
-	LastDate[uins] = date;
+	LastDate[uins] = date.date();
 }
 
 QList<QDate> HistoryManager::getMessageDates(const UinsList &uins)
 {
 	QFile messageDatesFile(ggPath("history/") + getFileNameByUinsList(uins) + ".message_dates");
-	if (!messageDatesFile.exists())
+	if (!messageDatesFile.exists() || (messageDatesFile.size() == 0))
 		createMessageDates(uins);
 
 	QList<QDate> result;
@@ -1307,8 +1338,8 @@ void HistoryManager::addMyMessage(const UinsList &senders, const QString &msg)
 	if (!config_file.readBoolEntry("History", "Logging"))
 		return;
 	kdebugf();
-	time_t current=time(NULL);
-	if (bufferedMessages.find(senders[0])!=bufferedMessages.end())
+	time_t current = time(NULL);
+	if (bufferedMessages.find(senders[0]) != bufferedMessages.end())
 	{
 		bufferedMessages[senders[0]].append(BuffMessage(senders, msg, 0, current, true, 0));
 		checkImageTimeout(senders[0]);
@@ -1316,7 +1347,7 @@ void HistoryManager::addMyMessage(const UinsList &senders, const QString &msg)
 	else
 		appendMessage(senders, senders[0], msg, true, 0, true, current);
 
-	updateMessageDates(senders);
+	//updateMessageDates(senders, current);
 
 	kdebugf2();
 }
