@@ -1,16 +1,16 @@
 #ifndef HISTORY_SEARCH_DIALOG_H
 #define HISTORY_SEARCH_DIALOG_H
 
-#include <qdialog.h>
+#include <QtGui/QDialog>
 
 #include "gadu.h"
 
+class QButtonGroup;
 class QCheckBox;
 class QComboBox;
-class QHGroupBox;
+class QGroupBox;
 class QLineEdit;
 class QRadioButton;
-class QVButtonGroup;
 
 struct HistoryFindRec {
 	QDateTime fromdate;
@@ -22,8 +22,25 @@ struct HistoryFindRec {
 	HistoryFindRec();
 };
 
-class HistorySearchDialog : public QDialog {
+class HistorySearchDialog : public QDialog 
+{
 	Q_OBJECT
+
+	protected:
+		QGroupBox *fromGroupBox, *toGroupBox, *phraseGroupBox, *statusGroupBox;
+		QCheckBox *fromCheckBox, *toCheckBox, *reverseCheckBox;
+		QComboBox *fromDayComboBox, *fromMonthComboBox, *fromYearComboBox, *fromHourComboBox, *fromMinComboBox;
+		QComboBox *toDayComboBox, *toMonthComboBox, *toYearComboBox, *toHourComboBox, *toMinComboBox;
+		QComboBox *statusComboBox;
+		QLineEdit *phraseEdit;
+		QButtonGroup *criteriaButtonGroup;
+		QGroupBox *criteriaGroupBox;
+		QRadioButton *phraseRadioButton , *statusRadioButton ;
+		QStringList numsList;
+		UinsList uins;
+
+		void resetFromDate();
+		void resetToDate();
 	public:
 		HistorySearchDialog(QWidget *parent, UinsList uins);
 		void setDialogValues(HistoryFindRec &findrec);
@@ -38,21 +55,6 @@ class HistorySearchDialog : public QDialog {
 		void findBtnClicked();
 		void cancelBtnClicked();
 		void resetBtnClicked();
-
-	protected:
-		QHGroupBox *from_hgb, *to_hgb, *phrase_hgb, *status_hgb;
-		QCheckBox *from_chb, *to_chb, *reverse_chb;
-		QComboBox *from_day_cob, *from_month_cob, *from_year_cob, *from_hour_cob, *from_min_cob;
-		QComboBox *to_day_cob, *to_month_cob, *to_year_cob, *to_hour_cob, *to_min_cob;
-		QComboBox *status_cob;
-		QLineEdit *phrase_edit;
-		QVButtonGroup *criteria_bg;
-		QRadioButton *phrase_rb, *status_rb;
-		QStringList numslist;
-		UinsList uins;
-
-		void resetFromDate();
-		void resetToDate();
 };
 
 #endif
