@@ -108,6 +108,14 @@
         <source>Unknown</source>
         <translation>Sconosciuto</translation>
     </message>
+    <message>
+        <source>Clear history</source>
+        <translation>Cancella Cronologia</translation>
+    </message>
+    <message>
+        <source>Rebuild index</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HistoryManager</name>
@@ -123,6 +131,22 @@
         <source>No</source>
         <translation>No</translation>
     </message>
+    <message>
+        <source>Error opening history file </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error opening sms history file </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error opening new history file </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error opening new sms history file </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HistoryModule</name>
