@@ -38,6 +38,12 @@
 #define MODULE_MEDIAPLAYER_VERSION 1.2
 #define CHECK_STATUS_INTERVAL 10*1000 /* 10s */
 
+#ifdef Q_OS_WIN
+#define SHORTCUT_KEY Qt::Key_Meta
+#else
+#define SHORTCUT_KEY Qt::Key_Super_L
+#endif
+
 const char *MediaPlayerSyntaxText = QT_TRANSLATE_NOOP
 (
 	"@default",
@@ -67,7 +73,7 @@ MediaPlayer *mediaplayer;
 const char *mediaPlayerOsdHint = "MediaPlayerOsd";
 
 // Kadu initializing functions
-extern "C" int mediaplayer_init(bool firstLoad)
+extern "C" KADU_EXPORT int mediaplayer_init(bool firstLoad)
 {
 	mediaplayer = new MediaPlayer(firstLoad);
 	notification_manager->registerEvent(mediaPlayerOsdHint, QT_TRANSLATE_NOOP("@default", "Pseudo-OSD for MediaPlayer"), CallbackNotRequired);
@@ -77,7 +83,7 @@ extern "C" int mediaplayer_init(bool firstLoad)
 	return 0;
 }
 
-extern "C" void mediaplayer_close()
+extern "C" KADU_EXPORT void mediaplayer_close()
 {
 	MainConfigurationWindow::unregisterUiFile(dataPath("kadu/modules/configuration/mediaplayer.ui"), mediaplayer);
 
@@ -240,14 +246,17 @@ void MediaPlayer::chatKeyPressed(QKeyEvent *e, CustomInput *k, bool &handled)
 {
 	kdebugf();
 
-	if (!config_file.readBoolEntry("MediaPlayer", "chatShortcuts", true) || !isActive())
+	if (!config_file.readBoolEntry("MediaPlayer", "chatShortcuts", true))
 		return;
 
-	if (e->key() == Qt::Key_Super_L)
+	if (e->key() == SHORTCUT_KEY)
 		winKeyPressed = true; // We want to handle LeftWinKey pressed state
 	else if (!winKeyPressed)
 		return; // If LeftWinKey isn't pressed then break function.
 
+	if (!isActive())
+		return;
+
 	handled = true;
 
 	switch (e->key())
@@ -287,7 +296,7 @@ void MediaPlayer::chatKeyPressed(QKeyEvent *e, CustomInput *k, bool &handled)
 
 void MediaPlayer::chatKeyReleased(QKeyEvent *e, CustomInput *k, bool &handled)
 {
-	if (e->key() == Qt::Key_Super_L)
+	if (e->key() == SHORTCUT_KEY)
 		winKeyPressed = false; // We want to handle LeftWinKey pressed state
 }
 
@@ -637,14 +646,12 @@ void MediaPlayer::checkTitle()
 		putTitleHint(title);
 
 	bool checked;
-	int idx = dockMenu->indexOf(popups[5]);
-	if (idx != -1)
-		checked = dockMenu->isItemChecked(popups[5]);
+	if (mediaplayerStatus != NULL)
+		checked = mediaplayerStatus->isChecked();
+	else if (enableMediaPlayerStatuses->action(kadu))
+		checked = enableMediaPlayerStatuses->action(kadu)->isChecked();
 	else
-		if (enableMediaPlayerStatuses->action(kadu))
-			checked = enableMediaPlayerStatuses->action(kadu)->isChecked();
-		else
-			checked = false;
+		checked = false;
 
 	if (!gadu->currentStatus().isOffline() && checked)
 	{
@@ -672,8 +679,7 @@ void MediaPlayer::configurationUpdated()
 	// Statuses switch
 	bool enabled;
 
-	int idx = dockMenu->indexOf(popups[5]);
-	if (idx == -1)
+	if (mediaplayerStatus == NULL)
 	{
 		if (enableMediaPlayerStatuses->action(kadu))
 			enabled = enableMediaPlayerStatuses->action(kadu)->isChecked();
@@ -681,15 +687,16 @@ void MediaPlayer::configurationUpdated()
 	}
 	else
 	{
-		enabled = dockMenu->isItemChecked(popups[5]);
-		dockMenu->removeItem(popups[5]);
+		enabled = mediaplayerStatus->isChecked();
+		dockMenu->removeAction(mediaplayerStatus);
 	}
 
-	bool menuPos = config_file.readBoolEntry("MediaPlayer", "dockMenu", false);
-	if (menuPos)
+	if (config_file.readBoolEntry("MediaPlayer", "dockMenu", false))
 	{
-		popups[5] = dockMenu->insertItem(tr("Enable MediaPlayer statuses"), this, SLOT(toggleStatuses(int)), 0, -1, 10);
-		dockMenu->setItemChecked(popups[5], enabled);
+		mediaplayerStatus = new QAction(tr("Enable MediaPlayer statuses"), this);
+		mediaplayerStatus->setCheckable(true);
+		connect(mediaplayerStatus, SIGNAL(toggled(bool)), this, SLOT(toggleStatuses(bool)));
+		dockMenu->addAction(mediaplayerStatus);
 	}
 	else
 	{
