@@ -82,6 +82,14 @@ Notify::Notify(QObject *parent, const char *name)
 	connect(userlist, SIGNAL(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)),
 		this, SLOT(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)));
 
+	silent_mode = config_file.readBoolEntry("Notify", "SilentMode", false);
+	silent_action = new ActionDescription(
+		ActionDescription::TypeGlobal, "silentModeAction",
+		this, SLOT(silentActionActivated(QAction *, bool)),
+		"SilentMode", tr("Enable Silent Mode"), true, tr("Disable Silent Mode")
+	);
+	connect(silent_action, SIGNAL(actionCreated(KaduAction *)), this, SLOT(setSilentActionState()));
+
 	MessageNotification::registerEvents(this);
 	ConnectionErrorNotification::registerEvent(this);
 	StatusChangedNotification::registerEvents(this);
@@ -89,6 +97,40 @@ Notify::Notify(QObject *parent, const char *name)
 	kdebugf2();
 }
 
+void Notify::silentActionActivated(QAction  *action, bool is_on)
+{
+	Q_UNUSED(action)
+	kdebugf();
+	silent_mode = is_on;
+ 	foreach (KaduAction *action, silent_action->actions())
+		action->setChecked(silent_mode);
+	config_file.writeEntry("Notify", "SilentMode", silent_mode);
+	kdebugf2();
+}
+
+void Notify::setSilentActionState()
+{
+ 	foreach (KaduAction *action, silent_action->actions())
+		action->setChecked(silent_mode);
+}
+
+void Notify::checkSilentMode()
+{
+	static int silent_mode_enabled = 0;
+	if (config_file.readBoolEntry("Notify", "AwaySilentMode") && gadu->currentStatus().isBusy())
+	{
+		silent_mode_enabled = 1;
+		silent_mode = 1;
+		setSilentActionState();
+	}
+	else if (silent_mode_enabled)
+	{
+		silent_mode_enabled = 0;
+		silent_mode = 0;
+		setSilentActionState();
+	}
+}
+
 Notify::~Notify()
 {
 	kdebugf();
@@ -104,6 +146,9 @@ Notify::~Notify()
 	disconnect(userlist, SIGNAL(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)),
 		this, SLOT(statusChanged(UserListElement, QString, const UserStatus &, bool, bool)));
 
+	delete silent_action;
+	silent_action = 0;
+
 	if (!Notifiers.isEmpty())
 	{
 		kdebugm(KDEBUG_WARNING, "WARNING: not unregistered notifiers found! (%u)\n", Notifiers.size());
@@ -315,6 +360,10 @@ void Notify::statusChanged(UserListElement elem, QString protocolName,
 {
 	kdebugf();
 
+	checkSilentMode();
+	if (silent_mode)
+		return;
+
 	if (massively && config_file.readBoolEntry("Notify", "NotifyIgnoreOnConnection"))
 	{
 		kdebugmf(KDEBUG_FUNCTION_END, "end: ignore on connection\n");
@@ -360,6 +409,10 @@ void Notify::messageReceived(Protocol *protocol, UserListElements senders, const
 {
 	kdebugf();
 
+	checkSilentMode();
+	if (silent_mode)
+		return;
+
 	ChatWidget *chat = chat_manager->findChatWidget(senders);
 	if (!chat) // new chat
 		notify(new MessageNotification(MessageNotification::NewChat, senders, msg, protocol->protocolID()));
@@ -374,6 +427,10 @@ void Notify::connectionError(Protocol *protocol, const QString &server, const QS
 {
 	kdebugf();
 
+	checkSilentMode();
+	if (silent_mode)
+		return;
+
 	if (!ConnectionErrorNotification::activeError(message))
 	{
 		ConnectionErrorNotification *connectionErrorNotification = new ConnectionErrorNotification(server, message, protocol->protocolID());
