@@ -31,18 +31,20 @@
 #include "misc.h"
 #include "config_file.h"
 #include "icons_manager.h"
+#include "message_box.h"
 
-QString kaduConfFile = "kadu.conf.xml";
+#include "exports.h"
 
-extern QMutex GlobalMutex;
+static const QString kaduConfFile = "kadu.conf.xml";
+extern KADUAPI QMutex GlobalMutex; // ugly..
 
-extern "C" int profiles_init()
+extern "C" KADU_EXPORT int profiles_init()
 {
 	profileManager = new ProfileManager();
 	return 0;
 }
 
-extern "C" void profiles_close()
+extern "C" KADU_EXPORT void profiles_close()
 {
 	delete profileManager;
 	profileManager = 0;
@@ -56,16 +58,11 @@ ProfileManager::ProfileManager(QObject *parent, const char *name)
 {
 	dialogWindow = new ProfileConfigurationWindow();
 
-	ProfileMenu = new QMenu("ProfileMenu", kadu);
+	ProfileMenu = new QMenu("Profiles...", kadu);
+	ProfileMenu->setIcon(icons_manager->loadIcon("Profiles"));
+	
 	connect(ProfileMenu, SIGNAL(aboutToShow()), this, SLOT(createProfileMenu()));
-	
-	profileMenuActionDescription = new ActionDescription(
-		ActionDescription::TypeMainMenu, "profileManagerAction",
-		this, SLOT(showMenu()),
-		"Profiles", tr("Profiles...")
-	);
-	kadu->insertMenuActionDescription(0, profileMenuActionDescription);
-	
+	kadu->insertMenuSubmenu(0, ProfileMenu);
 	getProfiles();
 	
 	//odpal te ktore maja autostart
@@ -78,9 +75,8 @@ ProfileManager::~ProfileManager()
 	kdebugf();
 	
 	disconnect(ProfileMenu, SIGNAL(aboutToShow()), this, SLOT(createProfileMenu()));
-
-	kadu->removeMenuActionDescription(profileMenuActionDescription);
-	delete profileMenuActionDescription;
+	kadu->removeMenuSubmenu(ProfileMenu);
+	delete ProfileMenu;
 	delete dialogWindow;
 	
 	//czyszcze liste watkow
@@ -95,7 +91,11 @@ ProfileManager::~ProfileManager()
 }
 
 QString ProfileManager::dirString() {
-	return ggPath()+"kadupro/clones/";
+#ifdef Q_OS_WIN
+	return ggPath() + "kadupro\\clones\\";
+#else
+	return ggPath() + "kadupro/clones/";
+#endif
 }
 
 void ProfileManager::showMenu()
@@ -139,7 +139,7 @@ void ProfileManager::firstRun()
 	//jak katalog nie istnieje to stworz nowy
 	if (!directory.exists())
 	{
-		directory.mkdir(ggPath()+"kadupro", true);
+		directory.mkdir(ggPath() + "kadupro", true);
 		directory.mkdir(dirnameString, true);
 	}
 	else
@@ -286,11 +286,12 @@ void ProfileManager::runAutostarted()
 		if (p.autostart == true)
 		{
 			QString profilePath = p.directory;
+#ifndef Q_OS_WIN
 			profilePath = profilePath.right(profilePath.length() - profilePath.find(".kadu"));
+#endif
 			runKadu(profilePath, p.protectPassword);
 		}
 	}
-	
 }
 
 static inline void startThread(QString profilePath)
@@ -361,8 +362,9 @@ void ProfileManager::openProfile(int index)
 
 	Profile p = list.at(index);
 	QString profilePath = p.directory;
+#ifndef Q_OS_WIN
 	profilePath = profilePath.right(profilePath.length() - profilePath.find(".kadu"));
-
+#endif
 	runKadu(profilePath, p.protectPassword);
 
 	kdebugf2();
@@ -492,8 +494,9 @@ void ProfileConfigurationWindow::openBtnPressed()
 	if (profileName->text().compare("") == 0) return;
 	
 	QString profilePath = this->profileDir->text();
+#ifndef Q_OS_WIN
 	profilePath = profilePath.right(profilePath.length()-profilePath.find(".kadu"));
-
+#endif
 	//uruchom kadu w nowym watku
 	if (profileManager->runKadu(profilePath,
 		 	passwordProtectCheck->isChecked() ? protectPassword->text() : "")) 
@@ -618,24 +621,34 @@ void ProfileConfigurationWindow::deleteBtnPressed()
 	{
 		//usun katalog i jego pliki
 		QDir directory(profileDir->text(), QString::null, QDir::Name, QDir::Files);
-		if (directory.exists()) {
-			//to tak na wszelki wypadek by komus nie wyciac systemu		
-			if ((QString::compare(profileDir->text(), "/") == 0) ||
-				(QString::compare(profileDir->text(), "/bin") == 0) ||
-				(QString::compare(profileDir->text(), "/boot") == 0) ||	
-				(QString::compare(profileDir->text(), "/dev") == 0) ||	
-				(QString::compare(profileDir->text(), "/etc") == 0) ||
-				(QString::compare(profileDir->text(), "/lib") == 0) ||
-				(QString::compare(profileDir->text(), "/mnt") == 0) ||	
-				(QString::compare(profileDir->text(), "/opt") == 0) ||
-				(QString::compare(profileDir->text(), "/proc") == 0) ||			
-				(QString::compare(profileDir->text(), "/sbin") == 0) ||
-				(QString::compare(profileDir->text(), "/sys") == 0) ||
-				(QString::compare(profileDir->text(), "/usr") == 0) ||
-				(QString::compare(profileDir->text(), "/var") == 0))
-					return;			
+		if (directory.exists()) 
+		{
+#ifdef Q_OS_WIN
+			if ((QString::compare(profileDir->text(), "C:\\") == 0) ||
+				(QString::compare(profileDir->text(), "C:\\WINDOWS") == 0) ||
+				(QString::compare(profileDir->text(), "C:\\WINDOWS\\system32") == 0))
+					return;
 			
-			system("rm -fr "+profileDir->text());
+			system("rd /S /Q " + profileDir->text());
+#else
+			//to tak na wszelki wypadek by komus nie wyciac systemu
+			if ((QString::compare(profileDir->text(), "/")     == 0) ||
+			    (QString::compare(profileDir->text(), "/bin")  == 0) ||
+			    (QString::compare(profileDir->text(), "/boot") == 0) ||
+			    (QString::compare(profileDir->text(), "/dev")  == 0) ||
+			    (QString::compare(profileDir->text(), "/etc")  == 0) ||
+			    (QString::compare(profileDir->text(), "/lib")  == 0) ||
+			    (QString::compare(profileDir->text(), "/mnt")  == 0) ||
+			    (QString::compare(profileDir->text(), "/opt")  == 0) ||
+			    (QString::compare(profileDir->text(), "/proc") == 0) ||
+			    (QString::compare(profileDir->text(), "/sbin") == 0) ||
+			    (QString::compare(profileDir->text(), "/sys")  == 0) ||
+			    (QString::compare(profileDir->text(), "/usr")  == 0) ||
+			    (QString::compare(profileDir->text(), "/var")  == 0))
+				return;
+
+			system("rm -fr " + profileDir->text());
+#endif
 		}
 	
 		removeProfile(profileName->text());
@@ -670,8 +683,6 @@ void ProfileConfigurationWindow::profileSelected(QListWidgetItem *item)
 
 	Profile p = profileManager->getProfile(item->text());
 
-	if (index == 0) return;
-
 	profileName->setText(p.name);
 	profileDir->setText(p.directory);
 	profileUIN->setText(p.uin);
@@ -758,7 +769,12 @@ void ProfileConfigurationWindow::removeProfile(QString name)
 
 void MyThread::run()
 {
-	system("bash -c \"export CONFIG_DIR="+path+" ; "+command+"\"");	
+#ifdef Q_OS_WIN
+	QString s = command + " --config-dir \"" + path + "\"";
+#else
+	QString s = "bash -c \"export CONFIG_DIR=" + path + " ; " + command + "\"";
+#endif
+	system(qPrintable(s));
 }
 
 
