@@ -22,7 +22,17 @@
 #include <QtGui/QLabel>
 #include <QtGui/QMenu>
 #include <QtGui/QPainter>
+#ifdef Q_WS_X11
 #include <QtGui/QX11Info>
+#elif defined (Q_WS_WIN)
+#include <QLibrary>
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#undef MessageBox
+typedef BOOL (WINAPI *PrintWindow_t)(HWND hwnd, HDC  hdcBlt, UINT nFlags);
+#elif defined Q_WS_MAC
+#include <Carbon/Carbon.h>
+#endif
 
 #include "action.h"
 #include "chat_edit_box.h"
@@ -37,9 +47,11 @@
 
 #include "screenshot.h"
 
+#include "exports.h"
+
 ScreenShot* screenShot;
 
-extern "C" int screenshot_init(bool firstLoad)
+extern "C" KADU_EXPORT int screenshot_init(bool firstLoad)
 {
 	kdebugf();
 
@@ -50,7 +62,7 @@ extern "C" int screenshot_init(bool firstLoad)
 	return 0;
 }
 
-extern "C" void screenshot_close()
+extern "C" KADU_EXPORT void screenshot_close()
 {
 	kdebugf();
 
@@ -110,7 +122,9 @@ ScreenShot::ScreenShot(bool firstLoad)
 	menu = new QMenu();
 	menu->addAction(tr("Simple shot"), this, SLOT(takeShot()));
 	menu->addAction(tr("With chat window hidden"), this, SLOT(takeShotWithChatWindowHidden()));
+#ifndef Q_WS_MAC
 	menu->addAction(tr("Window shot"), this, SLOT(takeWindowShot()));
+#endif
 
 	UiHandler = new ScreenShotConfigurationUiHandler();
 
@@ -542,7 +556,7 @@ void ScreenShot::createDefaultConfiguration()
 // Code below is copied (and changed a little) from KSnapShot,
 // copyrighted by Bernd Brandstetter <bbrand@freenet.de>.
 // It's licenced with GPL.
-
+#ifdef Q_WS_X11
 static bool operator < ( const QRect& r1, const QRect& r2 )
 {
     return r1.width() * r1.height() < r2.width() * r2.height();
@@ -717,3 +731,97 @@ Window ScreenShot::findRealWindow( Window w, int depth )
 
 // End of code copied from KSnapShot
 //////////////////////////////////////////////////////////////////
+#elif defined Q_WS_WIN
+
+QPixmap ScreenShot::grabCurrent()
+{
+	kdebugf();
+	POINT p;
+	HWND winId = 0;
+	if(GetCursorPos(&p))
+		winId = WindowFromPoint(p);
+
+	// find top level window
+	while(winId){
+		LONG style = GetWindowLong(winId, GWL_STYLE);
+
+		if(!(style & WS_CHILD))
+			break;
+
+		winId=GetParent(winId);
+	}
+
+
+	if(winId){
+		RECT rect;
+		GetWindowRect(winId, &rect);
+		int width = rect.right - rect.left;
+		int height = rect.bottom - rect.top;
+		PrintWindow_t PrintWindow_f=(PrintWindow_t)QLibrary::resolve("user32", "PrintWindow");
+		if(!PrintWindow_f){
+			kdebugmf(KDEBUG_WARNING, "Old windows detected, using hack..\n");
+			// ugly hack..
+			HWND hwndFg=GetForegroundWindow();
+			SetForegroundWindow(winId);
+
+			// repaint window
+			SendMessage(winId, WM_PAINT, 0, 0);
+
+			QPixmap desktop = QPixmap::grabWindow(QApplication::desktop()->winId());
+
+			SetForegroundWindow(hwndFg);
+
+			// and copy windows content
+			return desktop.copy(rect.left, rect.top, width, height);
+		}
+		else
+		{
+			HDC hDC = GetWindowDC(winId);
+			HDC hdcMem = CreateCompatibleDC(hDC);
+
+			HBITMAP hBitmap = CreateCompatibleBitmap(hDC, width, height);
+			SelectObject(hdcMem, hBitmap);
+			PrintWindow_f(winId, hdcMem, NULL);
+
+			DeleteDC(hdcMem);
+			ReleaseDC(winId, hDC);
+
+			QPixmap ret=QPixmap::fromWinHBITMAP(hBitmap);
+
+			DeleteObject(hBitmap);
+			return ret;
+		}
+	}
+	else
+		return QPixmap();
+	
+}
+
+#elif defined Q_WS_MAC
+
+QPixmap ScreenShot::grabCurrent()
+{
+	WindowRef window;
+	Point mousePos;
+	Rect rect;
+	int err;
+
+	GetGlobalMouse(&mousePos);
+
+	/* This code works only with our application windows. 
+	 * In order to capture other application's windows the private CoreGraphics API must be used.
+	 */
+	err = MacFindWindow(mousePos, &window);
+	err = GetWindowBounds(window, kWindowStructureRgn, &rect);
+	if (err == noErr)
+	{
+		QPixmap desktop = QPixmap::grabWindow(QApplication::desktop()->winId());
+		return desktop.copy(rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top);
+	}
+	else
+		return QPixmap();
+}
+
+#endif
+
+
