@@ -1,71 +1,57 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="pl">
+<!DOCTYPE TS><TS>
 <context>
     <name>@default</name>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="52"/>
         <source>SMS</source>
         <translation>SMS</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="49"/>
         <source>General</source>
         <translation>Ogólne</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="11"/>
         <source>Nick</source>
         <translation>Nick</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="14"/>
         <source>SMS Nick</source>
         <translation>Nick SMS</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="19"/>
         <source>Application</source>
         <translation>Aplikacja</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="22"/>
         <source>Use built-in SMS application</source>
         <translation>Używaj wbudowanej aplikacji SMS</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="25"/>
         <source>Custom SMS application</source>
         <translation>Własna aplikacja SMS</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="28"/>
         <source>Use SMS custom string</source>
         <translation>Używaj własnych argumentów SMS</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="30"/>
         <source>Check this box if your sms application doesn&apos;t understand arguments: number &amp;message&amp;
 Arguments should be separated with spaces. %n argument is converted to number, %m to message</source>
         <translation>Zaznacz to okienko jeżeli aplikacja SMS nie rozpoznaje argumentów: numer &amp;wiadomość&amp;
 Argumenty powinny być oddzielone spacjami. %n jest zamieniane na numer, %m na wiadomość</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="33"/>
         <source>SMS custom string</source>
         <translation>Argumenty SMS</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="38"/>
         <source>Gateways</source>
         <translation>Bramki</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="46"/>
         <source>Shortcuts</source>
         <translation>Skróty</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="55"/>
         <source>Send SMS</source>
         <translation>Wyślij SMS</translation>
     </message>
@@ -73,59 +59,48 @@ Argumenty powinny być oddzielone spacjami. %n jest zamieniane na numer, %m na w
 <context>
     <name>Sms</name>
     <message>
-        <location filename="../sms.cpp" line="229"/>
         <source>Recipient</source>
         <translation>Odbiorca</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="260"/>
         <source>Send SMS</source>
         <translation>Wyślij SMS</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="356"/>
         <source>Sms application was not specified. Visit the configuration section</source>
         <translation>Wpisz nazwę programu do wysyłania SMS w konfiguracji.</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="382"/>
         <source>Could not spawn child process. Check if the program is functional</source>
         <translation>Problem z uruchomieniem programu do wysyłania SMS.</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="392"/>
         <source>The process exited normally. The SMS should be on its way</source>
         <translation>Proces zakończony prawidłowo. SMS powinien być już w drodze.</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="394"/>
         <source>The process exited abnormally. The SMS may not be sent</source>
         <translation>Proces zakończony nieprawidłowo. SMS mógł nie zostać wysłany.</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="232"/>
         <source>Contact</source>
         <translation>Kontakt</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="241"/>
         <source>Signature</source>
         <translation>Podpis</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="247"/>
         <source>Save SMS in history</source>
         <translation>Zapisz SMS w historii</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="421"/>
         <source>The SMS was sent and should be on its way.
 Do you want to send next message?</source>
         <translation>SMS został wysłany i prawdopodobnie jest w drodze.
 Chcesz wysłać następną wiadomość?</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="253"/>
         <source>&amp;Send</source>
         <translation>&amp;Wyślij</translation>
     </message>
@@ -133,22 +108,18 @@ Chcesz wysłać następną wiadomość?</translation>
 <context>
     <name>SmsConfigurationUiHandler</name>
     <message>
-        <location filename="../sms.cpp" line="627"/>
         <source>Send SMS</source>
         <translation>Wyślij SMS</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="661"/>
         <source>Up</source>
         <translation>Przenieś w górę</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="662"/>
         <source>Down</source>
         <translation>Przenieś w dół</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="671"/>
         <source>Gateways priorites</source>
         <translation>Priorytety bramek</translation>
     </message>
@@ -156,7 +127,6 @@ Chcesz wysłać następną wiadomość?</translation>
 <context>
     <name>SmsGateway</name>
     <message>
-        <location filename="../sms.cpp" line="126"/>
         <source>Network error. Provider gateway page is probably unavailable</source>
         <translation>Wskazana bramka SMS jest prawdopodobnie wyłączona.</translation>
     </message>
@@ -164,17 +134,14 @@ Chcesz wysłać następną wiadomość?</translation>
 <context>
     <name>SmsImageDialog</name>
     <message>
-        <location filename="../sms.cpp" line="78"/>
         <source>Enter text from the picture:</source>
         <translation>Wpisz tekst z obrazka:</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="87"/>
         <source>Ok</source>
         <translation>Ok</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="88"/>
         <source>Cancel</source>
         <translation>Anuluj</translation>
     </message>
@@ -182,17 +149,14 @@ Chcesz wysłać następną wiadomość?</translation>
 <context>
     <name>SmsSender</name>
     <message>
-        <location filename="../sms.cpp" line="163"/>
         <source>Mobile number is incorrect</source>
         <translation>Numer telefonu jest nieprawidłowy</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="179"/>
         <source>Mobile number is incorrect or gateway is not available</source>
         <translation>Numer telefonu jest niepoprawny lub bramka jest niedostępna</translation>
     </message>
     <message>
-        <location filename="../sms.cpp" line="170"/>
         <source>Signature can&apos;t be empty</source>
         <translation>Pole &quot;Podpis&quot; nie może być puste</translation>
     </message>
