@@ -1,6 +1,5 @@
-#include <qdragobject.h>
+#include <QtGui/QDrag>
 
-#include "chat_widget.h"
 #include "config_file.h"
 #include "hot_key.h"
 #include "icons_manager.h"
@@ -18,7 +17,7 @@ TabWidget::TabWidget()
 	connect(tabbar, SIGNAL(deleteTab(int)),
 			SLOT(onDeleteTab(int)));
 	connect(tabbar, SIGNAL(wheelEventSignal(QWheelEvent*)),
-			SLOT(wheelEvent(QWheelEvent*)));
+			SLOT(wheelEventSlot(QWheelEvent*)));
 	connect(tabbar,SIGNAL(mouseDoubleClickEventSignal(QMouseEvent*)),
 			SLOT(mouseDoubleClickEvent(QMouseEvent*)));
 	//przycisk otwarcia nowej karty pokazywany w lewym górnym rogu
@@ -36,6 +35,12 @@ TabWidget::TabWidget()
 	openChatWithWindow=NULL;
 }
 
+void TabWidget::closeChatWidget(ChatWidget *chat)
+{
+	if (chat)
+		delete chat;
+}
+
 void TabWidget::closeEvent(QCloseEvent* e)
 {
 	//w zależności od opcji w konfiguracji zamykamy wszystkie karty, lub tylko aktywną	
@@ -70,11 +75,6 @@ void TabWidget::chatKeyPressed(QKeyEvent* e, CustomInput* k, bool &handled)
 		switchTabLeft();
 	else if(HotKey::shortCut(e, "ShortCuts", "SwitchTabRight"))
 		switchTabRight();
-	else if(HotKey::shortCut(e, "ShortCuts", "chat_close"))
-	{
-		QWidget* current = currentPage();
-		delete current;
-	}
 	else
 		// skrót nie został znaleziony i wykonany. Przekazujemy zdarzenie dalej
 		handled = false;
@@ -85,6 +85,14 @@ void TabWidget::onContextMenu(int id, const QPoint& pos)
 	emit contextMenu(page(id), pos);
 }
 
+void TabWidget::wheelEventSlot(QWheelEvent* e)
+{
+	if (e->delta() > 0)
+		switchTabLeft();
+	else
+		switchTabRight();
+}
+
 void TabWidget::moveTab(int from, int to)
 {
 	kdebugf();
@@ -110,14 +118,6 @@ void TabWidget::onDeleteTab(int id)
 	delete chat;
 }
 
-void TabWidget::wheelEvent(QWheelEvent* e)
-{
-	if (e->delta() > 0)
-		switchTabLeft();
-	else
-		switchTabRight();
-}
-
 void TabWidget::switchTabLeft()
 {
 	if (currentPageIndex() == 0)
@@ -154,8 +154,11 @@ void TabWidget::dragEnterEvent(QDragEnterEvent* e)
 {
 	kdebugf();
 	// Akceptujemu dnd jeśli pochodzi on z UserBox'a lub paska kart
-	e->accept((UlesDrag::canDecode(e) && (dynamic_cast<UserBox*>(e->source())) || 
-		(QTextDrag::canDecode(e) && dynamic_cast<TabBar*>(e->source()))));
+	if ((UlesDrag::canDecode(e) && (dynamic_cast<UserBox*>(e->source()))) || (e->mimeData()->hasText() && dynamic_cast<TabBar*>(e->source())))
+		e->acceptProposedAction();
+	else
+		e->ignore();
+		
 	kdebugf2();
 }
 
@@ -163,27 +166,28 @@ void TabWidget::dropEvent(QDropEvent* e)
 {
 	kdebugf();
 	QStringList ules;
-	QString altnicks;
+
 	// Jeśli dnd pochodził z userboxa próbujemy dodać nową kartę
 	if (dynamic_cast<UserBox*>(e->source()) && UlesDrag::decode(e, ules))
 	{
-		if (tabbar->selectTab(e->pos()))
+		if (tabbar->tabAt(e->pos()) != -1)
 		// Jeśli w miejscu upuszczenia jest karta, dodajemy na jej pozycji
-			emit openTab(ules, tabbar->indexOf(tabbar->selectTab(e->pos())->identifier()));
+			emit openTab(ules, tabbar->tabAt(e->pos()));
 		else
 		// Jeśli nie na końcu tabbara
 			emit openTab(ules, -1);
 	}
 	// Jeśli dnd pochodził z tabbara, zmieniamy pozycję kart
-	else if(dynamic_cast<TabBar*>(e->source()) && QTextDrag::decode(e, altnicks))
+	else if(dynamic_cast<TabBar*>(e->source()) && e->mimeData()->hasText())
 	{
+		QString altnicks = e->mimeData()->text();
 		// karta źródłowa
 		int movingTabId = altnicks.toUInt(); 
 		// karta docelowa
 		int destinationTabId;
-		if (tabbar->selectTab(e->pos())) 
+		if (tabbar->tabAt(e->pos()) != -1) 
 		// jeśli w miejscu upuszczenia jest inna karta staje się ona kartą docelową
-			destinationTabId = tabbar->indexOf(tabbar->selectTab(e->pos())->identifier());
+			destinationTabId = tabbar->tabAt(e->pos());
 		else
 		// Jeśli nie to kartą docelową jest ostatnia karta
 			destinationTabId = count() - 1;
@@ -191,15 +195,18 @@ void TabWidget::dropEvent(QDropEvent* e)
                          // zamieniamy miejcami kartę źródłową z docelową
 			moveTab(movingTabId, destinationTabId);
 	}
+
 	kdebugf2();
 }
 
 void TabWidget::windowActivationChange(bool oldActive)
 {
 	kdebugf();
-	if (isActiveWindow() && !oldActive && dynamic_cast<ChatWidget*>(currentPage()))
+	ChatWidget *chat = dynamic_cast<ChatWidget*>(currentPage());
+	if (isActiveWindow() && !oldActive && chat)
 	{
-		emit chatWidgetActivated(dynamic_cast<ChatWidget*>(currentPage()));
+		chat->markAllMessagesRead(); 
+		emit chatWidgetActivated(chat);
 	}
 	kdebugf2();
 }
@@ -208,7 +215,7 @@ void TabWidget::mouseDoubleClickEvent(QMouseEvent* e)
 {
 	kdebugf();
 	// jeśli dwuklik nastąpil lewym przyciskiem myszy pokazujemy okno openchatwith
-	if(e->button() == LeftButton)
+	if(e->button() == Qt::LeftButton)
 		newChat();
 	kdebugf2();
 }
@@ -218,10 +225,10 @@ void TabWidget::newChat()
 	// jeśli okno openchatwith nie istnieje tworzymy nowe
 	if (!openChatWithWindow)
 	{
-		openChatWithWindow = new OpenChatWith(this, "open_chat_with");
+		openChatWithWindow = new OpenChatWith;
    		connect(openChatWithWindow, SIGNAL(destroyed()), this, SLOT(openChatWithWindowClose()));
 		// zapisujemy geometrię okna, aby ją później przywrócić (tabsy nie będą psuły pozycji okna z akcji kadu)
-		// TO DO: jet to obejście problemu. W przyszłości zrobić to ładniej ;) (piszę jak Vogel ;p)
+		// TO DO: jet to obejście problemu. W przyszłości zrobić to ładniej ;) (piszę jak Vogel ;p)[Ja też tak często miewam - Juzef]
 		openTabWithGeometry = openChatWithWindow->frameGeometry();
 		// pokazujemy je w miejscu w którym nastąpiło wywołanie metody (obecnie znajduje się kursor)
 		openChatWithWindow->setGeometry(QCursor::pos().x(), QCursor::pos().y(), openChatWithWindow->width(), openChatWithWindow->height());// jak wykonuje się to po pokazaniu okienkoa występuje denerwujące miganie
@@ -231,7 +238,7 @@ void TabWidget::newChat()
 	else
 	{
 		openChatWithWindow->setGeometry(QCursor::pos().x(), QCursor::pos().y(), openChatWithWindow->width(), openChatWithWindow->height());// jak wykonuje się to po pokazaniu okienka występuje denerwujące miganie
-		openChatWithWindow->setWindowState(openChatWithWindow->windowState() & ~WindowMinimized);
+		openChatWithWindow->setWindowState(openChatWithWindow->windowState() & Qt::WindowMinimized);
 		openChatWithWindow->raise();
 	}
 }
@@ -254,7 +261,7 @@ void TabWidget::openChatWithWindowClose()
 	po użyciu delete obiekt ;) A w jednym zdaniu zabezpieczamy się przed wysypem modułu i mamy pewność czy okno jest
 	otwarte czy nie)
 	*/	
-	openChatWithWindow=NULL;
+	openChatWithWindow = 0;
 }
 
 void TabWidget::configurationUpdated()
@@ -271,7 +278,7 @@ void TabWidget::configurationUpdated()
 }
 
 TabBar::TabBar(QWidget *parent, char *name)
-	: QTabBar(parent, name)
+	: QTabBar(parent)
 {
 	// dzięki temu sygnał mouseMoveEvent jest emitowany także w momencie "zwykłego" poruszania się kursora myszy nad tabbarem
 	setMouseTracking(true);
@@ -287,17 +294,12 @@ TabBar::TabBar(QWidget *parent, char *name)
 	crossButton->setAutoRaise(true);
 	// domyśnie żadna karta nie jest "naciśnięta" (nie znajduje się na niej przycisk zamknięcia)
 	clickedItem=-1;
-	// Podłączamy się do sygnału emitowanego po jakiejkolwiek zmianie wyglądu tabbara. 
-	// Dzięki temu mozemy uaktualniać pozycję przycisku zamknięcia na kartach np. w chwili zamknięcia karty.
-   	connect(this, SIGNAL(layoutChanged()), SLOT(replaceCross()));
 }
 
 void TabBar::mousePressEvent(QMouseEvent* e)
 {
-	QTab* selectedtab = selectTab(e->pos());
-
-	if (selectedtab && e->button() == RightButton)
-		emit contextMenu(indexOf(selectedtab->identifier()), mapToGlobal(e->pos()));
+	if (tabAt(e->pos()) != -1 && e->button() == Qt::RightButton)
+		emit contextMenu(tabAt(e->pos()), mapToGlobal(e->pos()));
 	MouseStart = e->pos();
 
 	QTabBar::mousePressEvent(e);
@@ -305,10 +307,8 @@ void TabBar::mousePressEvent(QMouseEvent* e)
 
 void TabBar::mouseReleaseEvent(QMouseEvent* e)
 {
-	QTab* selectedtab = selectTab(e->pos());
-
-	if (selectedtab && e->button() == MidButton)
-		emit deleteTab(indexOf(selectedtab->identifier()));
+	if (tabAt(e->pos()) != -1 && e->button() == Qt::MidButton)
+		emit deleteTab(tabAt(e->pos()));
 	QTabBar::mouseReleaseEvent(e);
 }
 
@@ -321,25 +321,32 @@ void TabBar::mouseMoveEvent(QMouseEvent* e)
 {
 	kdebugf();
 	// Jeśli zaznaczona jest karta i wciśnięty lewy przycisk myszy, inicjujemy dnd
-	if ((e->state() & LeftButton) && (selectTab(MouseStart)) && ((MouseStart - e->pos()).manhattanLength() >= 15))
+	if ((e->state() & Qt::LeftButton) && (tabAt(MouseStart) != -1) && ((MouseStart - e->pos()).manhattanLength() >= 15))
 	{
 		// "przenoszonym" tekstem jest numer aktywowanej karty
-		QString drag_text = QString::number(indexOf(selectTab(MouseStart)->identifier()));
+		QString drag_text = QString::number(tabAt(MouseStart));
 		// Bezpośrednia inicjacja dnd
-		QDragObject* d = new QTextDrag(drag_text, this);
-		d->dragCopy();
+		QDrag* drag = new QDrag(this);
+		QMimeData *mimeData = new QMimeData;
+
+		mimeData->setText(drag_text);
+		drag->setMimeData(mimeData);
+
+		drag->exec(Qt::CopyAction);
 	}
+
 	// pomysł rozwiazania zaczęrpnięty z QDevelop
 	// Jeśli aktywna jest opcja pokazywania przycisku zamknięcia na kartach i w obrębie zdarzenia jest karta
-	else if (selectTab(e->pos()) && showCloseButton)
+	else if (tabAt(e->pos()) != -1 && showCloseButton)
 	{
 		// pokazujemy przycik na odpowiedniej pozycji
-		clickedItem = indexOf(selectTab(e->pos())->identifier()); 
+		clickedItem = tabAt(e->pos()); 
 		// pierwszy parametr ustawia przycisk 5 pixeli od prawej krawędzi karty.         
-		crossButton->setGeometry(tabAt(clickedItem)->rect().x()+tabAt(clickedItem)->rect().width()-crossButton->width()-5, 6, crossButton->width(), crossButton->height());
+		crossButton->setGeometry(tabRect(clickedItem).x()+tabRect(clickedItem).width()-crossButton->width()-5, 6, crossButton->width(), crossButton->height());
                 crossButton->show();
 	}
 	else
+
 		QTabBar::mouseMoveEvent(e);
 	kdebugf2();
 }
@@ -366,7 +373,7 @@ void TabBar::mouseDoubleClickEvent(QMouseEvent* e)
 void TabBar::setShowCloseButton(bool show)
 {
 	// odświeżenie ikonki
-   	crossButton->setIconSet(icons_manager->loadIcon("TabsClose"));	
+   	crossButton->setPixmap(icons_manager->loadPixmap("TabsClose"));	
 
 	showCloseButton = show;
 	// w zaleźności czy w konfiguracji włączone jest pokazywanie przycisku zamykania na kartach ukrywamy go lub pokazujemy
@@ -374,15 +381,22 @@ void TabBar::setShowCloseButton(bool show)
 		crossButton->hide();
 }
 
+void TabBar::tabLayoutChange()
+{
+	QTabBar::tabLayoutChange();
+	replaceCross();
+} 
+
 void TabBar::replaceCross()
 {
 	// jeśli przycisk zamknięciakarty jest widoczny na karcie i w miejscu kursora znajuje się karta
-	if(crossButton->isShown() && selectTab(mapFromGlobal(QCursor::pos())))
+	if(crossButton->isShown() && tabAt(mapFromGlobal(QCursor::pos())) != -1)
 	{
 		// uaktualniamy pozycję przycisku w prawym rogu karty
-		clickedItem = indexOf(selectTab(mapFromGlobal(QCursor::pos()))->identifier()); 
+		clickedItem = tabAt(mapFromGlobal(QCursor::pos())); 
 		// pierwszy parametr ustawia przycisk 5 pixeli od prawej krawędzi karty.
-		crossButton->setGeometry(tabAt(clickedItem)->rect().x()+tabAt(clickedItem)->rect().width()-crossButton->width()-5, 6, crossButton->width(), crossButton->height());
+		crossButton->setGeometry(tabRect(clickedItem).x()+tabRect(clickedItem).width()-crossButton->width()-5, 6, crossButton->width(), crossButton->height());
                 crossButton->show();
 	}
+
 }
