@@ -1483,6 +1483,10 @@ Zu viel Versuche mit falschem Passwort</translation>
         <source>&amp;Exit Kadu</source>
         <translation>Kadu &amp;verlassen</translation>
     </message>
+    <message>
+	<source>Show Pending Messages</source>
+	<translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Notify about user</source>
         <translation>Benachrichtige über Kontakt</translation>
@@ -1580,8 +1584,8 @@ Zu viel Versuche mit falschem Passwort</translation>
         <translation>Zeige Kontate ohne Beschreibung</translation>
     </message>
     <message>
-        <source>Show only online and description users</source>
-        <translation>Zeige nur Kontakte, die online sind und Beschreibung haben</translation>
+        <source>Show only online or description buddies</source>
+        <translation>Zeige nur Kontakte, die online sind oder Beschreibung haben</translation>
     </message>
     <message>
         <source>Show all users</source>
