@@ -1459,6 +1459,10 @@ Too many attempts with bad password</source>
         <source>&amp;Exit Kadu</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+	<source>Show Pending Messages</source>
+	<translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Configuration</source>
         <translation type="unfinished"></translation>
@@ -1552,7 +1556,7 @@ Too many attempts with bad password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show only online and description users</source>
+        <source>Show only online or description buddies</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
