@@ -1465,6 +1465,10 @@ Too many attempts with bad password</source>
         <source>&amp;Exit Kadu</source>
         <translation>&amp;Sortir de  Kadu</translation>
     </message>
+    <message>
+	<source>Show Pending Messages</source>
+	<translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Notify about user</source>
         <translation>Renseigne sur le contact</translation>
@@ -1564,7 +1568,7 @@ Too many attempts with bad password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show only online and description users</source>
+        <source>Show only online or description buddies</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
