@@ -1471,6 +1471,10 @@ Di più conessioni con il password incorretto</translation>
         <source>&amp;Exit Kadu</source>
         <translation>&amp;Termina Kadu</translation>
     </message>
+    <message>
+	<source>Show Pending Messages</source>
+	<translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Notify about user</source>
         <translation>Notifica contatto</translation>
@@ -1574,8 +1578,8 @@ Di più conessioni con il password incorretto</translation>
         <translation>Visualizza contatti senza descrizione</translation>
     </message>
     <message>
-        <source>Show only online and description users</source>
-        <translation>Visualizza solo contatti attivi con la descrizione</translation>
+        <source>Show only online or description buddies</source>
+        <translation>Visualizza solo contatti attivi o con la descrizione</translation>
     </message>
     <message>
         <source>Show all users</source>
