@@ -1486,6 +1486,10 @@ Zbyt wiele prób połączeń z niepoprawnym hasłem</translation>
         <source>&amp;Exit Kadu</source>
         <translation>&amp;Zakończ Kadu</translation>
     </message>
+    <message>
+        <source>Show Pending Messages</source>
+        <translation>Pokaż otrzymane wiadomości</translation>
+    </message>
     <message>
         <source>Notify about user</source>
         <translation>Powiadom o kontakcie</translation>
@@ -1590,8 +1594,8 @@ Czy na pewno tego chcesz?</translation>
         <translation>Pokaż kontakty bez opisu</translation>
     </message>
     <message>
-        <source>Show only online and description users</source>
-        <translation>Pokaż tylko kontakty dostępne i z opisem</translation>
+        <source>Show only online or description buddies</source>
+        <translation>Pokaż tylko kontakty dostępne lub z opisem</translation>
     </message>
     <message>
         <source>Show all users</source>
